camelot.camelot.model

Package camelot :: Package camelot :: Package model |
[hide private]
[frames] | no frames]

# Package model

source code

Submodules | [hide private]
camelot.camelot.model.authentication: Set of classes to store persons, organizations, relationships and permissions camelot.camelot.model.i18n: Set of classes to enable internationalization of the user interface camelot.camelot.model.memento: Set of classes to keep track of changes to objects and be able to restore their state camelot.camelot.model.synchronization: Functionallity to synchronize elements from the camelot database against other databases

Variables | [hide private]
| metadata = `MetaData()`
| __metadata__ = `MetaData()`